<?php

class PayshopProcessWebhook
{
    /**
     * @var PayshopProcessEvent
     */
    private $payshopProcessEvent;

    /**
     * Class constructor
     */
    public function __construct() {
        add_action('woocommerce_api_payshop_process_webhook', [$this, 'execute']);

        $this->payshopProcessEvent = new PayshopProcessEvent();
    }

    /**
     * Payment process with credit card
     *
     * @return void
     */
    public function execute()
    {
        try {
            $eventBasicInformation = PayshopEvent::getEvent();

            if ($this->unprocessableEvent($eventBasicInformation)) {
                return;
            }

            $this->payshopProcessEvent->execute($eventBasicInformation);
        } catch (\Throwable $e) {
            PayshopLog::generate($e->getMessage(), PayshopLog::LOG_SEVERITY_ERROR);

            echo $e->getMessage();

            http_response_code(500);
        }

        exit;
    }

    /**
     * Check if the event is unprocessable
     *
     * @param array $eventBasicInformation
     * @return bool
     */
    private function unprocessableEvent($eventBasicInformation)
    {
        $eventType = $eventBasicInformation['event_type'];

        return !in_array($eventType, [
            'payment.success',
            'instrument.invalid'
        ]);
    }

}
