<?php

if (!defined('ABSPATH')) {
    exit;
}

?>

<style>
    .overlap {
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background: rgba(0, 0, 0, 0.9);
        z-index: 99999;
    }

    .overlap-content {
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        width: 300px;
        background: #fff;
        z-index: 999999;
        padding: 20px;
        border-radius: 5px;
        text-align: center;

        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-items: center;
        gap: 32px;
    }

    .overlap-content p {
        margin-bottom: 0;
        margin-top: 10px;
    }

    #declined-mbway,
    #accepted-mbway,
    #waiting-mbway {
        display: none;
    }
</style>

<div>
    <div class="overlap" id="waiting-mbway">
        <div class="overlap-content">
            <h5><?= __('Waiting MBWay payment confirmation', 'payshop') ?></h5>
            <img width="250" src="<?= PAYSHOP_PLUGIN_URL ?>templates/img/loading.gif" />
            <p>
                <?= __('You can confirm the payment after close this page. ', 'payshop') ?>
                <?= __('In this case, you will receive a message with confirmation', 'payshop') ?>
            </p>
        </div>
    </div>

    <div class="overlap" id="accepted-mbway">
        <div class="overlap-content">
            <h4>
                <?= __('Payment Confirmed', 'payshop') ?>
            </h4>
            <p><?= __('Payment Confirmed on MBWay', 'payshop') ?></p>
            <button id="accepted-mbway-button">
                <?= __('Go to order Details', 'payshop') ?>
            </button>
        </div>
    </div>

    <div class="overlap" id="declined-mbway">
        <div class="overlap-content">
            <h4 class="payshop-error-color">
                <?= __('Declined Payment', 'payshop') ?>
            </h4>
            <p><?= __('Payment Declined on MBWay', 'payshop') ?></p>
            <button id="declined-mbway-button">
                <?= __('Go to order Details', 'payshop') ?>
            </button>
        </div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-1.12.4.min.js" integrity="sha256-ZosEbRLbNQzLpnKIkEdrPv7lOy9C27hHQ+Xp8a4MxAQ=" crossorigin="anonymous"></script>
<script>
    (function() {
        function displayById(elementId, display = 'block') {
            let element = document.getElementById(elementId);
            element.style.display = display;
        }

        function handlePopup(interval, popupId) {
            clearInterval(interval);
            displayById('waiting-mbway', 'none')
            displayById(popupId)

            document.getElementById(popupId + '-button').addEventListener('click', function() {
                if (popupId === 'accepted-mbway') {
                    document.getElementById(popupId).style.display = 'none';
                } else {
                    location.reload()
                }
            });
        }

        function checkMBWayPayment() {
            displayById('waiting-mbway', 'block');

            let interval = setInterval(function() {
                $.ajax({
                    url: '<?= get_site_url() ?>?wc-api=payshop_check_payment_mbway&order-id=<?= $orderId ?>',
                    success: function(data) {
                        if (data.status == 'paid') {
                            handlePopup(interval, 'accepted-mbway');
                        }

                        if (data.status == 'declined') {
                            handlePopup(interval, 'declined-mbway');
                        }
                    },
                    error: function(error) {
                        alert('An error occurred, please try again later');
                    }
                });
            }, 3000);
        }

        setTimeout(function() {
            checkMBWayPayment();
        }, 3000);
    })();
</script>